@@ -50,7 +50,7 @@ public:
         Reply, /**< A component to show a replied-to message. */
         LinkPreview, /**< A preview of a URL in the message. */
         LinkPreviewLoad, /**< A loading dialog for a link preview. */
-        Edit, /**< A text edit for editing a message. */
+        ChatBar, /**< A text edit for editing a message. */
         Verification, /**< A user verification session start message. */
         Loading, /**< The component is loading. */
         Other, /**< Anything that cannot be classified as another type. */
