@@ -4,10 +4,9 @@
 #pragma once
 
 #include <Quotient/jobs/basejob.h>
-#include <Quotient/omittable.h>
 
 class NeochatDeleteDeviceJob : public Quotient::BaseJob
 {
 public:
-    explicit NeochatDeleteDeviceJob(const QString &deviceId, const Quotient::Omittable<QJsonObject> &auth = {});
+    explicit NeochatDeleteDeviceJob(const QString &deviceId, const std::optional<QJsonObject> &auth = {});
 };
