@@ -654,14 +654,6 @@ Q_SIGNALS:
      */
     void showMessage(MessageType::Type messageType, const QString &message);
 
-    /**
-     * @brief Request a notification be shown for an invite to this room.
-     *
-     * @note This may later be blocked if there are any rules on where invites can
-     * come from, but this is not NeoChatRoom's responsibility.
-     */
-    void showInviteNotification(NeoChatRoom *room);
-
 public Q_SLOTS:
     /**
      * @brief Upload a file to the matrix server and post the file to the room.
