@@ -30,6 +30,7 @@ class PollHandler : public QObject
 {
     Q_OBJECT
     QML_ELEMENT
+    QML_UNCREATABLE("Use NeoChatRoom::poll")
 
     /**
      * @brief The question for the poll.
@@ -91,7 +92,7 @@ Q_SIGNALS:
     void hasEndedChanged();
 
 private:
-    const Quotient::PollStartEvent *m_pollStartEvent;
+    const Quotient::PollStartEvent *m_pollStartEvent = nullptr;
 
     void updatePoll(Quotient::RoomEventsRange events);
 
