@@ -134,16 +134,15 @@ void RoomManager::activateUserModel()
     m_userListModel->activate();
 }
 
-UriResolveResult RoomManager::resolveResource(const Uri &uri)
-{
-    return UriResolverBase::visitResource(m_connection, uri);
-}
-
 void RoomManager::resolveResource(const QString &idOrUri, const QString &action)
 {
-    Uri uri{idOrUri};
+    resolveResource(Uri{idOrUri}, action);
+}
+
+void RoomManager::resolveResource(Uri uri, const QString &action)
+{
     if (!uri.isValid()) {
-        Q_EMIT showMessage(MessageType::Warning, i18n("Malformed or empty Matrix id<br />%1 is not a correct Matrix identifier", idOrUri));
+        Q_EMIT showMessage(MessageType::Warning, i18n("Malformed or empty Matrix id<br />%1 is not a correct Matrix identifier", uri.toDisplayString()));
         return;
     }
 
@@ -237,7 +236,6 @@ void RoomManager::loadInitialRoom()
     }
 
     if (m_isMobile) {
-        // We still need to remember the last space on mobile
         setCurrentSpace(m_lastSpaceConfig.readEntry(m_connection->userId(), QString()), false);
         // We don't want to open a room on startup on mobile
         return;
@@ -260,6 +258,7 @@ void RoomManager::openRoomForActiveConnection()
         setCurrentSpace({}, false);
         return;
     }
+    setCurrentSpace(m_lastSpaceConfig.readEntry(m_connection->userId(), QString()), false);
     const auto &lastRoom = m_lastRoomConfig.readEntry(m_connection->userId(), QString());
     if (lastRoom.isEmpty() || !m_connection->room(lastRoom)) {
         setCurrentRoom({});
@@ -267,7 +266,6 @@ void RoomManager::openRoomForActiveConnection()
         m_currentRoom = nullptr;
         resolveResource(lastRoom);
     }
-    setCurrentSpace(m_lastSpaceConfig.readEntry(m_connection->userId(), QString()), false);
 }
 
 UriResolveResult RoomManager::visitUser(User *user, const QString &action)
@@ -315,7 +313,9 @@ void RoomManager::visitRoom(Room *r, const QString &eventId)
 
     // It's important that we compare room *objects* here, not just room *ids*, since we need to deal with the object changing when going invite -> joined
     if (m_currentRoom && m_currentRoom == room) {
-        Q_EMIT goToEvent(eventId);
+        if (!eventId.isEmpty()) {
+            Q_EMIT goToEvent(eventId);
+        }
     } else {
         setCurrentRoom(room->id());
     }
