@@ -142,15 +142,6 @@ TextHandler::handleRecieveRichText(Qt::TextFormat inputFormat, const NeoChatRoom
             // If the image does not have an explicit width, but has a vertical-align it's most likely an emoticon.
             // We must do some pre-processing for it to show up nicely in and around text.
             if (isEmoticon) {
-                // Remove any pre-existing height
-                extraAttributes.removeIf([](const QString &s) {
-                    return s.contains(QStringLiteral("height="));
-                });
-
-                // Make sure it's the same height as the rest of the text
-                const QFontMetrics metrics(QGuiApplication::font());
-                extraAttributes.append(QStringLiteral("height=\"%1\"").arg(metrics.height()));
-
                 // Align it properly
                 extraAttributes.append(QStringLiteral("style=\"%1\"").arg(customEmojiStyle));
             }
@@ -505,6 +496,7 @@ QString TextHandler::cleanAttributes(const QString &tag, const QString &tagStrin
             nextAttribute = tagString.mid(nextAttributeIndex, nextSpaceIndex - nextAttributeIndex);
 
             if (isAllowedAttribute(tag, getAttributeType(nextAttribute))) {
+                QString style;
                 if (tag == QStringLiteral("img") && getAttributeType(nextAttribute) == QStringLiteral("src")) {
                     QString attributeData = TextRegex::attributeData.match(getAttributeData(nextAttribute)).captured(1);
                     if (isAllowedLink(attributeData, true)) {
@@ -525,9 +517,19 @@ QString TextHandler::cleanAttributes(const QString &tag, const QString &tagStrin
                     if (attributeData == customEmojiStyle) {
                         outputString.append(u' ' + nextAttribute);
                     }
+                } else if (getAttributeType(nextAttribute) == QStringLiteral("data-mx-color")) {
+                    const QString attributeData = TextRegex::attributeData.match(getAttributeData(nextAttribute)).captured(1);
+                    style.append(u"color: " + attributeData + u';');
+                } else if (getAttributeType(nextAttribute) == QStringLiteral("data-mx-bg-color")) {
+                    const QString attributeData = TextRegex::attributeData.match(getAttributeData(nextAttribute)).captured(1);
+                    style.append(u"background-color: " + attributeData + u';');
                 } else {
                     outputString.append(u' ' + nextAttribute);
                 }
+
+                if (!style.isEmpty()) {
+                    outputString.append(u" style=\"" + style + u'"');
+                }
             }
             nextAttributeIndex = nextSpaceIndex + 1;
         }
